==> strace-4.11.tar.xz: strace-4.11/linux/hppa/errnoent.h <==
[  1] = "EPERM",
[  2] = "ENOENT",
[  3] = "ESRCH",
[  4] = "EINTR",
[  5] = "EIO",
[  6] = "ENXIO",
[  7] = "E2BIG",
[  8] = "ENOEXEC",
[  9] = "EBADF",
[ 10] = "ECHILD",
[ 11] = "EAGAIN",
[ 12] = "ENOMEM",
[ 13] = "EACCES",
[ 14] = "EFAULT",
[ 15] = "ENOTBLK",
[ 16] = "EBUSY",
[ 17] = "EEXIST",
[ 18] = "EXDEV",
[ 19] = "ENODEV",
[ 20] = "ENOTDIR",
[ 21] = "EISDIR",
[ 22] = "EINVAL",
[ 23] = "ENFILE",
[ 24] = "EMFILE",
[ 25] = "ENOTTY",
[ 26] = "ETXTBSY",
[ 27] = "EFBIG",
[ 28] = "ENOSPC",
[ 29] = "ESPIPE",
[ 30] = "EROFS",
[ 31] = "EMLINK",
[ 32] = "EPIPE",
[ 33] = "EDOM",
[ 34] = "ERANGE",
[ 35] = "ENOMSG",
[ 36] = "EIDRM",
[ 37] = "ECHRNG",
[ 38] = "EL2NSYNC",
[ 39] = "EL3HLT",
[ 40] = "EL3RST",
[ 41] = "ELNRNG",
[ 42] = "EUNATCH",
[ 43] = "ENOCSI",
[ 44] = "EL2HLT",
[ 45] = "EDEADLK",
[ 46] = "ENOLCK",
[ 47] = "EILSEQ",
[ 50] = "ENONET",
[ 51] = "ENODATA",
[ 52] = "ETIME",
[ 53] = "ENOSR",
[ 54] = "ENOSTR",
[ 55] = "ENOPKG",
[ 57] = "ENOLINK",
[ 58] = "EADV",
[ 59] = "ESRMNT",
[ 60] = "ECOMM",
[ 61] = "EPROTO",
[ 64] = "EMULTIHOP",
[ 66] = "EDOTDOT",
[ 67] = "EBADMSG",
[ 68] = "EUSERS",
[ 69] = "EDQUOT",
[ 70] = "ESTALE",
[ 71] = "EREMOTE",
[ 72] = "EOVERFLOW",
[160] = "EBADE",
[161] = "EBADR",
[162] = "EXFULL",
[163] = "ENOANO",
[164] = "EBADRQC",
[165] = "EBADSLT",
[166] = "EBFONT",
[167] = "ENOTUNIQ",
[168] = "EBADFD",
[169] = "EREMCHG",
[170] = "ELIBACC",
[171] = "ELIBBAD",
[172] = "ELIBSCN",
[173] = "ELIBMAX",
[174] = "ELIBEXEC",
[175] = "ERESTART",
[176] = "ESTRPIPE",
[177] = "EUCLEAN",
[178] = "ENOTNAM",
[179] = "ENAVAIL",
[180] = "EISNAM",
[181] = "EREMOTEIO",
[182] = "ENOMEDIUM",
[183] = "EMEDIUMTYPE",
[184] = "ENOKEY",
[185] = "EKEYEXPIRED",
[186] = "EKEYREVOKED",
[187] = "EKEYREJECTED",
[215] = "ENOSYM",
[216] = "ENOTSOCK",
[217] = "EDESTADDRREQ",
[218] = "EMSGSIZE",
[219] = "EPROTOTYPE",
[220] = "ENOPROTOOPT",
[221] = "EPROTONOSUPPORT",
[222] = "ESOCKTNOSUPPORT",
[223] = "EOPNOTSUPP",
[224] = "EPFNOSUPPORT",
[225] = "EAFNOSUPPORT",
[226] = "EADDRINUSE",
[227] = "EADDRNOTAVAIL",
[228] = "ENETDOWN",
[229] = "ENETUNREACH",
[230] = "ENETRESET",
[231] = "ECONNABORTED",
[232] = "ECONNRESET",
[233] = "ENOBUFS",
[234] = "EISCONN",
[235] = "ENOTCONN",
[236] = "ESHUTDOWN",
[237] = "ETOOMANYREFS",
[238] = "ETIMEDOUT",
[239] = "ECONNREFUSED",
[240] = "EREMOTERELEASE",
[241] = "EHOSTDOWN",
[242] = "EHOSTUNREACH",
[244] = "EALREADY",
[245] = "EINPROGRESS",
[246] = "EWOULDBLOCK",
[247] = "ENOTEMPTY",
[248] = "ENAMETOOLONG",
[249] = "ELOOP",
[251] = "ENOSYS",
[252] = "ENOTSUP",
[253] = "ECANCELLED",
[254] = "EOWNERDEAD",
[255] = "ENOTRECOVERABLE",
[256] = "ERFKILL",
[257] = "EHWPOISON",
[512] = "ERESTARTSYS",
[513] = "ERESTARTNOINTR",
[514] = "ERESTARTNOHAND",
[515] = "ENOIOCTLCMD",
[516] = "ERESTART_RESTARTBLOCK",
[517] = "EPROBE_DEFER",
[518] = "EOPENSTALE",
[521] = "EBADHANDLE",
[522] = "ENOTSYNC",
[523] = "EBADCOOKIE",
[524] = "ENOTSUPP",
[525] = "ETOOSMALL",
[526] = "ESERVERFAULT",
[527] = "EBADTYPE",
[528] = "EJUKEBOX",
[529] = "EIOCBQUEUED",

==> strace-4.12.tar.xz: strace-4.12/linux/hppa/errnoent.h <==
[  1] = "EPERM",
[  2] = "ENOENT",
[  3] = "ESRCH",
[  4] = "EINTR",
[  5] = "EIO",
[  6] = "ENXIO",
[  7] = "E2BIG",
[  8] = "ENOEXEC",
[  9] = "EBADF",
[ 10] = "ECHILD",
[ 11] = "EAGAIN",
[ 12] = "ENOMEM",
[ 13] = "EACCES",
[ 14] = "EFAULT",
[ 15] = "ENOTBLK",
[ 16] = "EBUSY",
[ 17] = "EEXIST",
[ 18] = "EXDEV",
[ 19] = "ENODEV",
[ 20] = "ENOTDIR",
[ 21] = "EISDIR",
[ 22] = "EINVAL",
[ 23] = "ENFILE",
[ 24] = "EMFILE",
[ 25] = "ENOTTY",
[ 26] = "ETXTBSY",
[ 27] = "EFBIG",
[ 28] = "ENOSPC",
[ 29] = "ESPIPE",
[ 30] = "EROFS",
[ 31] = "EMLINK",
[ 32] = "EPIPE",
[ 33] = "EDOM",
[ 34] = "ERANGE",
[ 35] = "ENOMSG",
[ 36] = "EIDRM",
[ 37] = "ECHRNG",
[ 38] = "EL2NSYNC",
[ 39] = "EL3HLT",
[ 40] = "EL3RST",
[ 41] = "ELNRNG",
[ 42] = "EUNATCH",
[ 43] = "ENOCSI",
[ 44] = "EL2HLT",
[ 45] = "EDEADLK",
[ 46] = "ENOLCK",
[ 47] = "EILSEQ",
[ 50] = "ENONET",
[ 51] = "ENODATA",
[ 52] = "ETIME",
[ 53] = "ENOSR",
[ 54] = "ENOSTR",
[ 55] = "ENOPKG",
[ 57] = "ENOLINK",
[ 58] = "EADV",
[ 59] = "ESRMNT",
[ 60] = "ECOMM",
[ 61] = "EPROTO",
[ 64] = "EMULTIHOP",
[ 66] = "EDOTDOT",
[ 67] = "EBADMSG",
[ 68] = "EUSERS",
[ 69] = "EDQUOT",
[ 70] = "ESTALE",
[ 71] = "EREMOTE",
[ 72] = "EOVERFLOW",
[160] = "EBADE",
[161] = "EBADR",
[162] = "EXFULL",
[163] = "ENOANO",
[164] = "EBADRQC",
[165] = "EBADSLT",
[166] = "EBFONT",
[167] = "ENOTUNIQ",
[168] = "EBADFD",
[169] = "EREMCHG",
[170] = "ELIBACC",
[171] = "ELIBBAD",
[172] = "ELIBSCN",
[173] = "ELIBMAX",
[174] = "ELIBEXEC",
[175] = "ERESTART",
[176] = "ESTRPIPE",
[177] = "EUCLEAN",
[178] = "ENOTNAM",
[179] = "ENAVAIL",
[180] = "EISNAM",
[181] = "EREMOTEIO",
[182] = "ENOMEDIUM",
[183] = "EMEDIUMTYPE",
[184] = "ENOKEY",
[185] = "EKEYEXPIRED",
[186] = "EKEYREVOKED",
[187] = "EKEYREJECTED",
[215] = "ENOSYM",
[216] = "ENOTSOCK",
[217] = "EDESTADDRREQ",
[218] = "EMSGSIZE",
[219] = "EPROTOTYPE",
[220] = "ENOPROTOOPT",
[221] = "EPROTONOSUPPORT",
[222] = "ESOCKTNOSUPPORT",
[223] = "EOPNOTSUPP",
[224] = "EPFNOSUPPORT",
[225] = "EAFNOSUPPORT",
[226] = "EADDRINUSE",
[227] = "EADDRNOTAVAIL",
[228] = "ENETDOWN",
[229] = "ENETUNREACH",
[230] = "ENETRESET",
[231] = "ECONNABORTED",
[232] = "ECONNRESET",
[233] = "ENOBUFS",
[234] = "EISCONN",
[235] = "ENOTCONN",
[236] = "ESHUTDOWN",
[237] = "ETOOMANYREFS",
[238] = "ETIMEDOUT",
[239] = "ECONNREFUSED",
[240] = "EREMOTERELEASE",
[241] = "EHOSTDOWN",
[242] = "EHOSTUNREACH",
[244] = "EALREADY",
[245] = "EINPROGRESS",
[246] = "EWOULDBLOCK",
[247] = "ENOTEMPTY",
[248] = "ENAMETOOLONG",
[249] = "ELOOP",
[251] = "ENOSYS",
[252] = "ENOTSUP",
[253] = "ECANCELED",
[254] = "EOWNERDEAD",
[255] = "ENOTRECOVERABLE",
[256] = "ERFKILL",
[257] = "EHWPOISON",
[512] = "ERESTARTSYS",
[513] = "ERESTARTNOINTR",
[514] = "ERESTARTNOHAND",
[515] = "ENOIOCTLCMD",
[516] = "ERESTART_RESTARTBLOCK",
[517] = "EPROBE_DEFER",
[518] = "EOPENSTALE",
[521] = "EBADHANDLE",
[522] = "ENOTSYNC",
[523] = "EBADCOOKIE",
[524] = "ENOTSUPP",
[525] = "ETOOSMALL",
[526] = "ESERVERFAULT",
[527] = "EBADTYPE",
[528] = "EJUKEBOX",
[529] = "EIOCBQUEUED",
